!  test_rho_PTXZ.f90 
!
!  FUNCTIONS:
!  test_rho_PTXZ  - compute density rho as a function of pressure P, 
!                   temperature T, hydrogene abundance X, and 
!                   metallicity Z 
!                   using SAHA_S3 equation of state
!

!****************************************************************************
!
!  PROGRAM: test_rho_PTXZ
!
!  PURPOSE:  Entry point for the console application.
!
!****************************************************************************

    program test3_rho_ptxz
    
    USE mod_etat_saha

    implicit none

    ! Variables
    
    REAL*8 P, T, rho_test
    REAL*8 H, He3, He4, Z
    
    REAL*8 ro,drop,drot,drox,u,dup,dut,dux
	REAL*8 delta,deltap,deltat,deltax,cp,dcpp,dcpt,dcpx
	REAL*8 gradad,dgradadp,dgradadt,dgradadx,alfa,beta, gamma1 
    
    LOGICAL deriv
    
       
    ! input data are from the solar model (SUN_saha_h, EOS - SAHA-S)
    ! r=1.88904502815E+000 (in cm, center of the Sun)
    
    T=1.56170574137E+007
    P=2.35561311452E+017
    rho_test=1.53000009142E+002
    
    H=3.46720637036E-001
    He3=7.88779509614E-006
    He4=6.33933559860E-001
    
    ! ----------
    
    
    Z=1-H-He3-He4 
    
    deriv=.true. 
    
    CALL etat_saha(P,T,H,Z,deriv, & 
       ro,drop,drot,drox,u,dup,dut,dux,      & 
       delta,deltap,deltat,deltax,cp,dcpp,dcpt,dcpx,  &
       gradad,dgradadp,dgradadt,dgradadx,alfa,beta,gamma1)
    
   PRINT*, 'ro       = ', ro
   PRINT*, 'rho_test = ', rho_test
   
!---------------------------------------------
  PRINT*,'Writing output file test_results.dat.'
  OPEN(unit=65, file='test_results.dat')
  
  WRITE(65,*) 'P,T,H,Z' 
  WRITE(65,*) 'ro,drop,drot,drox,'
  WRITE(65,*) 'u,dup,dut,dux,'
  WRITE(65,*) 'delta,deltap,deltat,deltax,'
  WRITE(65,*) 'cp,dcpp,dcpt,dcpx,'
  WRITE(65,*) 'gradad,dgradadp,dgradadt,dgradadx,'
  WRITE(65,*) 'alfa,beta,gamma1'
     
  WRITE(65,1005) P,T,H,Z
  WRITE(65,1005) ro,drop,drot,drox
  WRITE(65,1005) u,dup,dut,dux
  WRITE(65,1005) delta,deltap,deltat,deltax
  WRITE(65,1005) cp,dcpp,dcpt,dcpx
  WRITE(65,1005) gradad,dgradadp,dgradadt,dgradadx
  WRITE(65,1005) alfa,beta,gamma1 
  
  CLOSE(65)
   
1005      FORMAT(1x,4e19.11) 
    
   end program test3_rho_ptxz

